@@ -130,7 +130,7 @@ initCurveContinuation <- function(session, model, initstate, initparms, tanvec,
   cData$tanvec <- tanvec
   cData$testvals <- NULL
   cData$pntnr <- 1
-  cData$stepsize <- as.numeric(direction)*abs(nopts$maxstepsize) / 10.0
+  cData$stepsize <- as.numeric(direction)*abs(nopts$initstepsize)
   cData$direction <- as.numeric(direction)
 
   cData$tabname <- curtabname
