@@ -125,7 +125,8 @@ bifurcation <- function(model, state, parms, resume = TRUE, ...) {
                       args_run = unique(names(c(formals(deSolve::ode), formals(deSolve::lsoda)))),
                       methods_run = as.character(formals(deSolve::ode)$method),
                       rhstol = 1e-7, dytol = 1e-7, neartol = 0.05, jacdif = 1.0E-4, maxiter = 20,
-                      maxpoints = 1000, iszero = 1.0E-5, minstepsize = 1.0E-3, maxstepsize = 0.05,
+                      maxpoints = 1000, iszero = 1.0E-5,
+                      initstepsize = 5.0E-3, minstepsize = 1.0E-3, maxstepsize = 5.0E-2,
                       replotfreq = 10, ninterval = 10, glorder = 4, lcampl = 1.0E-3
     )
 
@@ -364,7 +365,7 @@ bifurcation <- function(model, state, parms, resume = TRUE, ...) {
               updatePlot(1)
               if (numopts$maxpoints > 1) {
                 busyComputing(1)
-                updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle"))
+                updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle", verify_fa = FALSE))
                 shinyjs::show("pausebtn")
                 shinyjs::show("stopbtn")
               } else {
@@ -441,13 +442,13 @@ bifurcation <- function(model, state, parms, resume = TRUE, ...) {
         busycomp <- as.numeric(isolate(busyComputing()))
         if (busycomp == 0) return(NULL)
         else if (busycomp == 1) {
-          updateActionButton(session, "pausebtn", label = "Continue", icon = icon("forward"))
+          updateActionButton(session, "pausebtn", label = "Continue", icon = icon("forward", verify_fa = FALSE))
           busyComputing(-1)
           changeCurveMenu(1)
           updatePlot(1)
         }
         else {
-          updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle"))
+          updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle", verify_fa = FALSE))
           busyComputing(1)
         }
       })
@@ -503,7 +504,7 @@ bifurcation <- function(model, state, parms, resume = TRUE, ...) {
         updatePlot(1)
         curveDirection(0)
         busyComputing(0)
-        updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle"))
+        updateActionButton(session, "pausebtn", label = "Pause", icon = icon("pause-circle", verify_fa = FALSE))
         shinyjs::hide("pausebtn")
         shinyjs::hide("stopbtn")
 
